---
title: Plugin
---

### Plugin

This section will go over how to use the plugin that comes with the Pages module.


#### structure

The `structure` function let's you generate navigation structure based on your pages structure.

The returned plugin criteria will render the resulting navigation automatically using `__toString()` if you do not explicitly call `render()`.

###### Returns: `\Anomaly\Streams\Platform\Addon\Plugin\PluginCriteria`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$root

</td>

<td>

false

</td>

<td>

mixed

</td>

<td>

none

</td>

<td>

The id, instance, or path of the root navigation page.

</td>

</tr>

</tbody>

</table>

###### Twig

    {{ structure()|raw }}

    {# Showing child page navigation #}
    {{ structure(template.page)
        .linkAttributesDropdown({'data-toggle': 'dropdown'})
        .listClass('nav navbar-nav navbar-right')
        .childListClass('dropdown-menu')
        .render()|raw }}


##### Available Options

The `structure` uses the plugin criteria to allow you to configure options for the resulting navigation.

Options are defined by chaining together `camelCase` methods:

    {{ structure().optionOne('example')|raw }} // Results in option_one = example

So to define `dropdown_class` for example you would do this:

    {{ structure().dropdownClass('dropdown')|raw }}

<div class="alert alert-info">**Pro Tip:** Defining criteria options this way is standard throughout Pyro!</div>

###### Options

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

view

</td>

<td>

false

</td>

<td>

anomaly.module.pages::structure

</td>

<td>

The base view to render the navigation from.

</td>

</tr>

<tr>

<td>

macro

</td>

<td>

false

</td>

<td>

anomaly.module.pages::macro

</td>

<td>

The macro to use for rendering the navigation.

</td>

</tr>

<tr>

<td>

depth

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The maximum depth of the navigation.

</td>

</tr>

<tr>

<td>

list_tag

</td>

<td>

false

</td>

<td>

ul

</td>

<td>

The list tag to use.

</td>

</tr>

<tr>

<td>

list_class

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The list class to use.

</td>

</tr>

<tr>

<td>

item_tag

</td>

<td>

false

</td>

<td>

li

</td>

<td>

The list item tag to use.

</td>

</tr>

<tr>

<td>

dropdown_class

</td>

<td>

false

</td>

<td>

dropdown

</td>

<td>

The CSS class for links containing child links.

</td>

</tr>

<tr>

<td>

active_class

</td>

<td>

false

</td>

<td>

active

</td>

<td>

The CSS class for links that are selected or whose child link is selected.

</td>

</tr>

<tr>

<td>

selected_class

</td>

<td>

false

</td>

<td>

current

</td>

<td>

The CSS class for the currently selected navigation link.

</td>

</tr>

<tr>

<td>

link_class

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The CSS class to use for links.

</td>

</tr>

<tr>

<td>

link_attributes

</td>

<td>

false

</td>

<td>

[]

</td>

<td>

An array of key value html attributes for links.

</td>

</tr>

<tr>

<td>

link_attributes_dropdown

</td>

<td>

false

</td>

<td>

[]

</td>

<td>

An array of key value html attributes for links that have a dropdown.

</td>

</tr>

<tr>

<td>

child_list_tag

</td>

<td>

false

</td>

<td>

list_tag

</td>

<td>

The list tag for child lists.

</td>

</tr>

<tr>

<td>

child_list_class

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The list class for child lists.

</td>

</tr>

<tr>

<td>

dropdown_toggle

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The dropdown toggle tag to use in the case a dropdown toggle is desired.

</td>

</tr>

<tr>

<td>

dropdown_toggle_class

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The dropdown toggle class to use in the case a dropdown toggle is desired.

</td>

</tr>

<tr>

<td>

dropdown_toggle_attributes

</td>

<td>

false

</td>

<td>

[]

</td>

<td>

An array of key value html attributes for the dropdown toggle.

</td>

</tr>

<tr>

<td>

dropdown_toggle_text

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The text or HTML to display inside the dropdown toggle.

</td>

</tr>

</tbody>

</table>


#### page

The `page` function returns the decorated instance of the desired page.

###### Returns: `\Anomaly\PagesModule\Page\PagePresenter` or `null`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$identifier

</td>

<td>

false

</td>

<td>

mixed

</td>

<td>

Current page

</td>

<td>

The id or path of the desired page.

</td>

</tr>

</tbody>

</table>

###### Twig

    <a href="{{ page('about/company').route('view') }}"></a>

    {# Displaying page content #}
    {{ page('about/contact').content()|raw }}
